GrpcExecResult class

Result of a raw gRPC transaction execution.

Constructors

GrpcExecResult({required bool success, String? error, List<GrpcChangedObject> changedObjects = const []})
const

Properties

changedObjects List<GrpcChangedObject>
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited